@@ -1,6 +1,14 @@
 def announce(something):
     """
-    ### Example:
+    Decorator function to announce a company announcement before executing the wrapped function.
+
+    Args:
+        something (str): The announcement to be made.
+
+    Returns:
+        function: The wrapper function.
+
+    Example:
     ```
     @announce("We are expanding our product line!")
     def my_function():
@@ -9,8 +17,6 @@ def announce(something):
     
     my_function()
     ```
-    
-       
     """
     def wrapper(func):
         def inner(*args, **kwargs):
