@@ -1,5 +1,6 @@
 def audited(func):
     """
+    #### This decorator checks if a function has been audited before allowing it to be executed.
 
     ### Example:
     ```
@@ -12,9 +13,10 @@ def audited(func):
 
     ```
     """
+    func.audited = True
     def wrapper(*args, **kwargs):
-        if func.__dict__.get('audited'):
+        if func.audited:
             return func(*args, **kwargs)
         else:
             raise Exception(f"{func.__name__} has not been audited.")
-    return wrapper
+    return wrapper
\ No newline at end of file
