@@ -1,4 +1,7 @@
 class StockIssuanceValidator:
+    """
+    #### Stock issuance validator is a decorator that validates if a stock issuance is compliant with listing conditions and does not cause changes to the controlling shareholder or actual controller.
+    """
     def __init__(self, func):
         self.func = func
 
@@ -15,16 +18,14 @@ class StockIssuanceValidator:
         return self.func(*args, **kwargs)
 
     def check_equity_distribution(self, *args, **kwargs):
-        # Add code here to check if the equity distribution is compliant
-        # with listing conditions
+        """
+        Check if the equity distribution is compliant with listing conditions
+        """
         return False
 
     def check_controlling_shareholder(self, *args, **kwargs):
-        # Add code here to check if the controlling shareholder or
-        # actual controller has changed
+        """
+        Check if the controlling shareholder or actual controller has changed
+        """
         return True
 
-@StockIssuanceValidator
-def issue_new_stocks(amount):
-    # Code to issue new stocks
-    print(f"Issuing {amount} new stocks")
\ No newline at end of file
